#
# spec file for package opencl-cpp-headers
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2024 Aaron Puchert.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           opencl-cpp-headers
Version:        2024.10.24
Release:        1.1
Summary:        OpenCL C++ headers
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://www.khronos.org/registry/OpenCL/
Source:         https://github.com/KhronosGroup/OpenCL-CLHPP/archive/v%{version}.tar.gz
BuildRequires:  dos2unix
BuildRequires:  findutils
Conflicts:      opencl-headers-1_2
BuildArch:      noarch
Requires:       opencl-headers

%description
OpenCL is a royalty-free standard for cross-platform, parallel programming
of modern processors found in personal computers, servers and
handheld/embedded devices.

This package provides the official C++ headers for OpenCL, which are wrappers
around the C headers.

%prep
%setup -q -n OpenCL-CLHPP-%{version}

%build
# Fix line endings
find -type f -exec dos2unix {} \;

%install
install -d -m 0755 %{buildroot}%{_includedir}/CL
install -p -m 0644 include/CL/* %{buildroot}%{_includedir}/CL

%files
%dir %{_includedir}/CL
%{_includedir}/CL/cl2.hpp
%{_includedir}/CL/opencl.hpp

%changelog
* Thu Nov 14 2024 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 2024.10.24.
  * Synchronize with OpenCL v3.0.17 specification release.
  * Support for the `cl_khr_external_semaphore_dx_fence` and
    `cl_khr_external_memory_dx` extensions was removed.
* Fri May 10 2024 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 2024.05.08.
  * Synchronize with OpenCL v3.0.16 specification release.
* Mon Dec 18 2023 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 2023.12.14.
  * Synchronize with OpenCL v3.0.15 specification release.
  * The device query for CL_DEVICE_PLATFORM now returns a
    cl::Platform instead of a cl_platform_id. Code wanting a
    cl_platform_id instead can access this from a cl::Platform
    using operator().
  * Querying the device handle list for a semaphore now requires
    using the semaphore-specific CL_SEMAPHORE_DEVICE_HANDLE_LIST_KHR
    enum, since the CL_DEVICE_HANDLE_LIST_KHR enum has been removed.
* Tue Apr 18 2023 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 2023.04.17.
  * Synchronize with OpenCL v3.0.14 specification release.
* Tue Feb  7 2023 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 2023.02.06.
  * Synchronize with OpenCL v3.0.13 specification release.
  * Note: this is the first OpenCL-CLHPP release with the new
    date-based naming convention.
* Tue Oct  4 2022 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 2.0.19.
  * Synchronize with OpenCL v3.0.12 specification release (with
    OpenCL-SDK fix).
* Tue Sep 27 2022 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 2.0.18.
  * Synchronize with OpenCL v3.0.12 specification release.
* Sat Jun  4 2022 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 2.0.17.
  * Synchronize with OpenCL v3.0.11 specification release.
* Tue Jan  4 2022 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 2.0.16.
  * Synchronize with OpenCL v3.0.10 specification release.
* Sat Jul  3 2021 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 2.0.15.
  * Synchronize with OpenCL v3.0.8 specification release.
* Fri May  7 2021 Ben Greiner <code@bnavigator.de>
- Include the actual headers: cl2.hpp is just importing the new
  opencl.hpp now.
* Sat May  1 2021 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 2.0.14.
  * Synchronize with OpenCL v3.0.7 specification release.
* Wed Jun 17 2020 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 2.0.12.
  * Relicense under Apache 2.0
  * Remove deprecated cl.hpp
  * Add support for cl_khr_extended_versioning
  * Various fixes / clean ups
* Sat Mar 14 2020 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 2.0.11.
* Sun Nov 19 2017 aaronpuchert@alice-dsl.net
- Added conflict with opencl-headers-1_2. The C++ headers were
  separated from the C headers starting only with version 2.0.
* Sun Nov 12 2017 aaronpuchert@alice-dsl.net
- Created package based on version 2.0.10.
